@@ -39,6 +39,18 @@
 //! ...
 //! ```
 //!
+//! For example,
+//!
+//! ```text
+//! 61516
+//! the // parent       1
+//! the function is     22
+//! the function a      4
+//! the function to     1
+//! the function and    1
+//! ...
+//! ```
+//!
 //! ## Examples
 //!
 //! The following code uses datasets in [`test_data`](https://github.com/kampersanda/tongrams-rs/tree/main/test_data) at the root of this repository.
@@ -65,6 +77,12 @@
 //! assert_eq!(lookuper.with_str("the same memory"), Some(8));
 //! assert_eq!(lookuper.with_str("vector is array"), None);
 //!
+//! // Gets the count of a query N-gram formed by a string array.
+//! assert_eq!(lookuper.with_tokens(&["vector"]), Some(182));
+//! assert_eq!(lookuper.with_tokens(&["in", "order"]), Some(47));
+//! assert_eq!(lookuper.with_tokens(&["the", "same", "memory"]), Some(8));
+//! assert_eq!(lookuper.with_tokens(&["vector", "is", "array"]), None);
+//!
 //! // Serializes the index into a writable stream.
 //! let mut data = vec![];
 //! lm.serialize_into(&mut data).unwrap();
@@ -97,13 +115,12 @@ pub use gram::Gram;
 pub use record::Record;
 pub use trie_count_lm::TrieCountLm;
 
-pub use loader::GramsLoader;
+pub use loader::{GramsFileFormats, GramsLoader};
 pub use parser::GramsParser;
-pub use vocabulary::Vocabulary;
 
-use rank_array::{EliasFanoRankArray, SimpleRankArray};
-use trie_array::{EliasFanoTrieArray, SimpleTrieArray};
-use vocabulary::{DoubleArrayVocabulary, SimpleVocabulary};
+pub use rank_array::{EliasFanoRankArray, RankArray, SimpleRankArray};
+pub use trie_array::{EliasFanoTrieArray, SimpleTrieArray, TrieArray};
+pub use vocabulary::{DoubleArrayVocabulary, SimpleVocabulary, Vocabulary};
 
 /// Simple implementation of [`TrieCountLm`].
 /// Note that this is for debug, and do NOT use it for storing massive datasets.
